import setuptools
import pkg_resources

pkg_resources.require('setuptools>=39.2')
setuptools.setup(
    version = "1.0.1",
    url = "https://github.com/machinexa2/WikiTools",
    download_url = 'https://github.com/machinexa2/WikiTools/archive/refs/tags/v1.0.0.tar.gz',
)
